==> com.liferay.layout.content.page.editor.web-2.0.74.jar: META-INF/resources/page_editor/app/components/layout-data-items/hasDropZoneChild.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.74/page_editor/app/components/layout-data-items/hasDropZoneChild", ['module', 'exports', 'require', '../../config/constants/layoutDataItemTypes'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports["default"] = hasDropZoneChild;

    var _layoutDataItemTypes = require("../../config/constants/layoutDataItemTypes");

    /**
     * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
     *
     * This library is free software; you can redistribute it and/or modify it under
     * the terms of the GNU Lesser General Public License as published by the Free
     * Software Foundation; either version 2.1 of the License, or (at your option)
     * any later version.
     *
     * This library is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
     * details.
     */
    function hasDropZoneChild(item, layoutData) {
      return item.children.some(function (childrenId) {
        var children = layoutData.items[childrenId];
        return children.type === _layoutDataItemTypes.LAYOUT_DATA_ITEM_TYPES.dropZone ? true : hasDropZoneChild(children, layoutData);
      });
    }
    //# sourceMappingURL=hasDropZoneChild.js.map
  }
});
//# sourceMappingURL=hasDropZoneChild.js.map

==> com.liferay.layout.content.page.editor.web-2.0.122.jar: META-INF/resources/page_editor/app/components/layout-data-items/hasDropZoneChild.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.122/page_editor/app/components/layout-data-items/hasDropZoneChild", ['module', 'exports', 'require', '../../config/constants/layoutDataItemTypes'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = hasDropZoneChild;

    var _layoutDataItemTypes = require("../../config/constants/layoutDataItemTypes");

    /**
     * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
     *
     * This library is free software; you can redistribute it and/or modify it under
     * the terms of the GNU Lesser General Public License as published by the Free
     * Software Foundation; either version 2.1 of the License, or (at your option)
     * any later version.
     *
     * This library is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
     * details.
     */
    function hasDropZoneChild(item, layoutData) {
      return item.children.some(function (childrenId) {
        var children = layoutData.items[childrenId];
        return children.type === _layoutDataItemTypes.LAYOUT_DATA_ITEM_TYPES.dropZone ? true : hasDropZoneChild(children, layoutData);
      });
    }
    //# sourceMappingURL=hasDropZoneChild.js.map
  }
});
//# sourceMappingURL=hasDropZoneChild.js.map
